/* This file was generated by syncqt. */
#ifndef QT_QTWEBVIEW_VERSION_H
#define QT_QTWEBVIEW_VERSION_H

#define QTWEBVIEW_VERSION_STR "5.15.15"

#define QTWEBVIEW_VERSION 0x050F0F

#endif // QT_QTWEBVIEW_VERSION_H
